Examples
========

There are several examples to help you see LensKit in action:

* The `Getting Started guide`_
* The `LensKit demo experiment`_

.. _Getting Started guide: GettingStarted.html
.. _LensKit demo experiment: https://github.com/lenskit/lk-demo-experiment


Old Examples
------------

These are examples of using LensKit 0.x in practice.  They have not been updated
to LensKit 2025.1 and later.

* Michael's `extended Book Gender paper`_ shows LensKit in use in an advanced experiment

.. _extended Book Gender paper: https://md.ekstrandom.net/pubs/bag-extended

In addition, PBS's `Crash Course AI episode on recommender systems`_ demonstrates
LensKit in the video and associated Collaboratory notebook.

.. _Crash Course AI episode on recommender systems:
    https://www.pbs.org/video/lets-make-a-movie-recommendation-system-lab-16-cmtwft/
